/* sample.sas -- Sample SAS program for calculating the three weight
variables for GIST analysis.

This sample program assumes: (1) The 'final' dataset consists of all
affected individuals, one per record, with variables 'famid' (family ID),
'allele1', 'allele2' (1st and 2nd alleles at the marker); (2) The
'final' dataset has already been sorted by 'famid'; (3) A macro
variable 'allele' has been defined to designate the target allele at
the marker.

The resulting 'count' dataset will have a record for each family, with
additinal three variables 'f1', 'f2', 'f3', for weights on the basis of
dominant, recessive, and additive models, respectively.

Chun Li, 02/18/2004, chun.li@vanderbilt.edu
*/

data final;
    set final;
    if allele1=. or allele2=. then delete;
run;

data count;
    set final;
    retain n c1 c2 c3;
    by famid;
    if first.famid then n=1; else n=n+1;
    if first.famid then do; c1=0; c2=0; c3=0; end;
    if allele1=&allele or allele2=&allele then c1=c1+1;
    if allele1=&allele and allele2=&allele then c2=c2+1;
    if allele1=&allele then c3=c3+1;
    if allele2=&allele then c3=c3+1;
    if last.famid then do; f1=c1/n; f2=c2/n; f3=c3/n/2; output; end;
run;
